#
# Unit Tests for Bob's install and uninstall methods
#

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Products.bob.config import *
from Products.bob.tests import BobTestCase

class testInstall(BobTestCase.BobTestCase):

    def afterSetUp(self):
        self.installer = getattr(self.portal, 'portal_quickinstaller')
        self.actions = getattr(self.portal, 'portal_actions')
        self.actionicons = getattr(self.portal, 'portal_actionicons')

    def testProductInstalled(self):
        self.failUnless(self.installer.isProductInstalled( PROJECTNAME ))

    def testActionCreated(self):
        cat, id = ACTION['category'], ACTION['id']
        self.failUnless(self.actions.getActionObject("%s/%s" %(cat, id))) 

    def testActioniconCreated(self):
        icons = [ icon for icon in self.actionicons._icons
                  if icon.getActionId() == ACTIONICON[1]
                  and icon.getIconURL() == ACTIONICON[2]
                  and icon.getTitle() == ACTIONICON[3] ]
        self.assertEqual(len(icons), 1)

class testActionAttributes(BobTestCase.BobTestCase):

    def afterSetUp(self):
        tool = getattr(self.portal, 'portal_actions')
        cat, id = ACTION['category'], ACTION['id']
        self.action = tool.getActionObject("%s/%s" %(cat, id))

    def testActionURL(self):
        self.assertEqual(self.action.getActionExpression(), ACTION['action'])

    def testActionCondition(self):
        self.assertEqual(self.action.getCondition(), ACTION['condition'])

    def testActionPermission(self):
        perm = self.action.getPermissions()[0]
        self.assertEqual(perm, ACTION['permission'])

    def testActionCategory(self):
        self.assertEqual(self.action.getCategory(), ACTION['category'])

    def testActionVisibility(self):
        self.assertEqual(self.action.getVisibility(), ACTION['visible'])

class testUninstall(BobTestCase.BobTestCase):

    def afterSetUp(self):
        self.installer = getattr(self.portal, 'portal_quickinstaller')
        self.actions = getattr(self.portal, 'portal_actions')
        self.actionicons = getattr(self.portal, 'portal_actionicons')
        self.installer.uninstallProducts(products=[PROJECTNAME])

    def testProductUninstalled(self):
        self.failIf(self.installer.isProductInstalled(PROJECTNAME))

    def testActionRemoved(self):
        cat, id = ACTION['category'], ACTION['id']
        self.failIf(self.actions.getActionObject("%s/%s" %(cat, id))) 

    def testActioniconRemoved(self):
        icons = [ icon for icon in self.actionicons._icons
                  if icon.getActionId() == ACTIONICON[1]
                  and icon.getIconURL() == ACTIONICON[2]
                  and icon.getTitle() == ACTIONICON[3] ]
        self.assertEqual(len(icons), 0)


if __name__ == '__main__':
    framework()
else:
    import unittest
    def test_suite():
        suite = unittest.TestSuite()
        suite.addTest(unittest.makeSuite(testInstall))
        suite.addTest(unittest.makeSuite(testActionAttributes))
        suite.addTest(unittest.makeSuite(testUninstall))
        return suite
